@@ -9,8 +9,8 @@
 """Unittests for EdFile"""
 
 __author__ = "Cody Precord <cprecord@editra.org>"
-__svnid__ = "$Id: testEdFile.py 65207 2010-08-07 22:39:49Z CJP $"
-__revision__ = "$Revision: 65207 $"
+__svnid__ = "$Id: testEdFile.py 67625 2011-04-27 01:33:05Z CJP $"
+__revision__ = "$Revision: 67625 $"
 
 #-----------------------------------------------------------------------------#
 # Imports
@@ -135,6 +135,15 @@ class EdFileTest(unittest.TestCase):
         new_bytes = common.GetFileContents(out)
         self.assertEquals(raw_bytes, new_bytes)
 
+    def testReadUTF32Bom(self):
+        """Test reading a file that has a UTF32 BOM"""
+        fname = common.GetDataFilePath('test_read_utf32_bom.txt')
+        fileutf32 = ed_txt.EdFile(fname)
+        data = fileutf32.Read()
+        self.assertTrue(fileutf32.HasBom(), "UTF-32 BOM not detected!")
+        self.assertTrue(fileutf32.Encoding in ("utf-32", "utf_32"),
+                        "Incorrect Encoding detected: %s" % fileutf32.Encoding)
+
     def testGetEncoding(self):
         """Test the encoding detection"""
         txt = self.file.Read()
